"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[858],{72463:(t,r,a)=>{a.d(r,{J3A:()=>i,TdP:()=>h});var e=a(61895);function i(t){return(0,e.k5)({tag:"svg",attr:{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round"},child:[{tag:"path",attr:{d:"M3 3v16a2 2 0 0 0 2 2h16"},child:[]},{tag:"rect",attr:{x:"7",y:"13",width:"9",height:"4",rx:"1"},child:[]},{tag:"rect",attr:{x:"7",y:"5",width:"12",height:"4",rx:"1"},child:[]}]})(t)}function h(t){return(0,e.k5)({tag:"svg",attr:{viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"2",strokeLinecap:"round",strokeLinejoin:"round"},child:[{tag:"path",attr:{d:"M15 3h6v6"},child:[]},{tag:"path",attr:{d:"M10 14 21 3"},child:[]},{tag:"path",attr:{d:"M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6"},child:[]}]})(t)}}}]);