@layer rdg{@layer Defaults,
    FocusSink,
    CheckboxInput,
    CheckboxIcon,
    CheckboxLabel,
    Cell,
    HeaderCell,
    SummaryCell,
    EditCell,
    Row,
    HeaderRow,
    SummaryRow,
    GroupedRow,
    Root}.mlln6zg7-0-0-beta-57{@layer rdg.MeasuringCell{contain:strict;grid-row:1;visibility:hidden}}.cj343x07-0-0-beta-57{@layer rdg.Cell{position:relative;padding-block:0;padding-inline:8px;border-inline-end:var(--rdg-border-width) solid var(--rdg-border-color);border-block-end:var(--rdg-border-width) solid var(--rdg-border-color);grid-row-start:var(--rdg-grid-row-start);align-content:center;background-color:inherit;white-space:nowrap;overflow:clip;text-overflow:ellipsis;outline:none;&[aria-selected=true]{outline:var(--rdg-selection-width) solid var(--rdg-selection-color);outline-offset:calc(var(--rdg-selection-width) * -1)}}}.csofj7r7-0-0-beta-57{@layer rdg.Cell{position:sticky;z-index:1;&:nth-last-child(1 of &){box-shadow:var(--rdg-cell-frozen-box-shadow)}}}.ch2wcw87-0-0-beta-57{@layer rdg.DragHandle{--rdg-drag-handle-size:8px;z-index:0;cursor:move;inline-size:var(--rdg-drag-handle-size);block-size:var(--rdg-drag-handle-size);background-color:var(--rdg-selection-color);place-self:end;&:hover{--rdg-drag-handle-size:16px;border:2px solid var(--rdg-selection-color);background-color:var(--rdg-background-color)}}}.c1wvphzh7-0-0-beta-57{@layer rdg.DragHandle{z-index:1;position:sticky}}.c1bn88vv7-0-0-beta-57{@layer rdg.CheckboxInput{display:block;margin-left:auto;margin-bottom:auto;margin-right:auto;margin-top:auto;inline-size:20px;block-size:20px;&:focus-visible{outline:2px solid var(--rdg-checkbox-focus-color);outline-offset:-3px}&:enabled{cursor:pointer}}}.g1s9ylgp7-0-0-beta-57{@layer rdg.GroupCellContent{outline:none}}.cz54e4y7-0-0-beta-57{@layer rdg.GroupCellCaret{margin-inline-start:4px;stroke:currentColor;stroke-width:1.5px;fill:transparent;vertical-align:middle;>path{transition:d .1s}}}.h44jtk67-0-0-beta-57{@layer rdg.SortableHeaderCell{display:flex}}.hcgkhxz7-0-0-beta-57{@layer rdg.SortableHeaderCellName{flex-grow:1;overflow:clip;text-overflow:ellipsis}}.c6ra8a37-0-0-beta-57{@layer rdg.Cell{background-color:#ccccff}}.cis5rrm7-0-0-beta-57{@layer rdg.EditCell{padding-left:0;padding-bottom:0;padding-right:0;padding-top:0}}.c6l2wv17-0-0-beta-57{@layer rdg.HeaderCell{cursor:pointer}}.c1kqdw7y7-0-0-beta-57{@layer rdg.HeaderCell{touch-action:none}}.r1y6ywlx7-0-0-beta-57{@layer rdg.HeaderCell{cursor:col-resize;position:absolute;inset-block-start:0;inset-inline-end:0;inset-block-end:0;inline-size:10px}}.c1bezg5o7-0-0-beta-57{@layer rdg.HeaderCell{background-color:var(--rdg-header-draggable-background-color)}}.c1vc96037-0-0-beta-57{@layer rdg.HeaderCell{background-color:var(--rdg-header-draggable-background-color)}}.d8rwc9w7-0-0-beta-57{@layer rdg.HeaderCell{border-radius:4px;width:fit-content;outline:2px solid hsl(207,100%,50%);outline-offset:-2px}}.r1upfr807-0-0-beta-57{@layer rdg.Row{display:contents;background-color:var(--rdg-background-color);&:hover{background-color:var(--rdg-row-hover-background-color)}&[aria-selected=true]{background-color:var(--rdg-row-selected-background-color);&:hover{background-color:var(--rdg-row-selected-hover-background-color)}}}}.r190mhd37-0-0-beta-57{@layer rdg.FocusSink{outline:2px solid var(--rdg-selection-color);outline-offset:-2px}}.r139qu9m7-0-0-beta-57{@layer rdg.FocusSink{&:before{content:"";display:inline-block;block-size:100%;position:sticky;inset-inline-start:0;border-inline-start:2px solid var(--rdg-selection-color)}}}.h10tskcx7-0-0-beta-57{@layer rdg.HeaderRow{display:contents;background-color:var(--rdg-header-background-color);font-weight:700;&>.cj343x07-0-0-beta-57{z-index:2;position:sticky}&>.csofj7r7-0-0-beta-57{z-index:3}}}.a3ejtar7-0-0-beta-57{@layer rdg.SortIcon{fill:currentColor;>path{transition:d .1s}}}.rnvodz57-0-0-beta-57{@layer rdg.Defaults{*,:after,:before{box-sizing:inherit}}@layer rdg.Root{--rdg-selection-width:2px;--rdg-selection-color:hsl(207,75%,66%);--rdg-font-size:14px;--rdg-cell-frozen-box-shadow:2px 0 5px -2px rgba(136,136,136,0.3);--rdg-border-width:1px;--rdg-summary-border-width:calc(var(--rdg-border-width) * 2);--rdg-color:light-dark(#000,#ddd);--rdg-border-color:light-dark(#ddd,#444);--rdg-summary-border-color:light-dark(#aaa,#555);--rdg-background-color:light-dark(hsl(0deg 0% 100%),hsl(0deg 0% 13%));--rdg-header-background-color:light-dark(hsl(0deg 0% 97.5%),hsl(0deg 0% 10.5%));--rdg-header-draggable-background-color:light-dark(hsl(0deg 0% 90.5%),hsl(0deg 0% 17.5%));--rdg-row-hover-background-color:light-dark(hsl(0deg 0% 96%),hsl(0deg 0% 9%));--rdg-row-selected-background-color:light-dark(hsl(207deg 76% 92%),hsl(207deg 76% 42%));--rdg-row-selected-hover-background-color:light-dark(hsl(207deg 76% 88%),hsl(207deg 76% 38%));--rdg-checkbox-focus-color:hsl(207deg 100% 69%);&.rdg-dark{--rdg-color-scheme:dark}&.rdg-light{--rdg-color-scheme:light}color-scheme:var(--rdg-color-scheme,light dark);&:dir(rtl){--rdg-cell-frozen-box-shadow:-2px 0 5px -2px rgba(136,136,136,0.3)}display:grid;accent-color:light-dark(hsl(207deg 100% 29%),hsl(207deg 100% 79%));contain:content;content-visibility:auto;block-size:350px;border-left-color:var(--rdg-border-color);border-left-style:solid;border-left-width:1px;border-bottom-color:var(--rdg-border-color);border-bottom-style:solid;border-bottom-width:1px;border-right-color:var(--rdg-border-color);border-right-style:solid;border-right-width:1px;border-top-color:var(--rdg-border-color);border-top-style:solid;border-top-width:1px;box-sizing:border-box;overflow:auto;background-color:var(--rdg-background-color);color:var(--rdg-color);font-size:var(--rdg-font-size);&:before{content:"";grid-column:1/-1;grid-row:1/-1}>:nth-last-child(1 of .rdg-top-summary-row){>.cj343x07-0-0-beta-57{border-block-end:var(--rdg-summary-border-width) solid var(--rdg-summary-border-color)}}>:nth-child(1 of .rdg-bottom-summary-row){>.cj343x07-0-0-beta-57{border-block-start:var(--rdg-summary-border-width) solid var(--rdg-summary-border-color)}}}}.vlqv91k7-0-0-beta-57{@layer rdg.Root{user-select:none;& .r1upfr807-0-0-beta-57{cursor:move}}}.f1lsfrzw7-0-0-beta-57{@layer rdg.FocusSink{grid-column:1/-1;pointer-events:none;z-index:1}}.f1cte0lg7-0-0-beta-57{@layer rdg.FocusSink{z-index:3}}.s8wc6fl7-0-0-beta-57{@layer rdg.SummaryCell{inset-block-start:var(--rdg-summary-row-top);inset-block-end:var(--rdg-summary-row-bottom)}}.skuhp557-0-0-beta-57{@layer rdg.SummaryRow{>.cj343x07-0-0-beta-57{position:sticky}}}.tf8l5ub7-0-0-beta-57{@layer rdg.SummaryRow{>.cj343x07-0-0-beta-57{z-index:2}>.csofj7r7-0-0-beta-57{z-index:3}}}.g1yxluv37-0-0-beta-57{@layer rdg.GroupedRow{&:not([aria-selected=true]){background-color:var(--rdg-header-background-color)}>.cj343x07-0-0-beta-57:not(:last-child,.csofj7r7-0-0-beta-57),>:nth-last-child(n+2 of .csofj7r7-0-0-beta-57){border-inline-end:none}}}.t7vyx3i7-0-0-beta-57{@layer rdg.TextEditor{appearance:none;box-sizing:border-box;inline-size:100%;block-size:100%;padding-block:0;padding-inline:6px;border-left-color:#ccc;border-left-style:solid;border-left-width:2px;border-bottom-color:#ccc;border-bottom-style:solid;border-bottom-width:2px;border-right-color:#ccc;border-right-style:solid;border-right-width:2px;border-top-color:#ccc;border-top-style:solid;border-top-width:2px;vertical-align:top;color:var(--rdg-color);background-color:var(--rdg-background-color);font-family:inherit;font-size:var(--rdg-font-size);&:focus{border-color:var(--rdg-selection-color);outline:none}&::placeholder{color:#999;opacity:1}}}.index-column{color:rgb(128,128,128);text-align:right}.diff-header-added{background-color:#3aa53a;color:white}.diff-cell-added{background-color:#cefece;color:black}.diff-header-removed{background-color:#ff6666;color:white}.diff-cell-modified,.diff-cell-removed{background-color:#ffc5c5;color:black}.cell-show-context-menu{overflow:visible}.grid-header:hover .key-icon,.grid-header:hover .pin-icon{display:block}.rdg-cell{border-width:0 1px 1px 0;border-style:solid;border-color:var(--rdg-border-color)}.rdg-row:hover .row-context-menu{visibility:visible;width:auto}